@@ -1,4 +1,3 @@
-import pickle
 import time
 import datetime
 import unittest
@@ -228,6 +227,9 @@ def test_isinstance_without_active():
 
 @freeze_time('2013-04-09')
 class TestUnitTestClassDecorator(unittest.TestCase):
+    def setUp(self):
+        self.assertEqual(datetime.date(2013,4,9), datetime.date.today())
+
     def test_class_decorator_works_on_unittest(self):
         self.assertEqual(datetime.date(2013,4,9), datetime.date.today())
 
@@ -276,33 +278,6 @@ def test_min_and_max():
     datetime.date.max.__class__.shouldnt.equal(FakeDate)
 
 
-def assert_pickled_datetimes_equal_original():
-    min_datetime = datetime.datetime.min
-    max_datetime = datetime.datetime.max
-    min_date = datetime.date.min
-    max_date = datetime.date.max
-    now = datetime.datetime.now()
-    today = datetime.date.today()
-    utc_now = datetime.datetime.utcnow()
-    assert pickle.loads(pickle.dumps(min_datetime)) == min_datetime
-    assert pickle.loads(pickle.dumps(max_datetime)) == max_datetime
-    assert pickle.loads(pickle.dumps(min_date)) == min_date
-    assert pickle.loads(pickle.dumps(max_date)) == max_date
-    assert pickle.loads(pickle.dumps(now)) == now
-    assert pickle.loads(pickle.dumps(today)) == today
-    assert pickle.loads(pickle.dumps(utc_now)) == utc_now
-
-
-def test_pickle():
-    freezer = freeze_time("2012-01-14")
-
-    freezer.start()
-    assert_pickled_datetimes_equal_original()
-
-    freezer.stop()
-    assert_pickled_datetimes_equal_original()
-
-
 @freeze_time("2014-07-30T01:00:00Z")
 def test_freeze_with_timezone_aware_datetime_in_utc():
     """
